#!/bin/bash

## Internationalization ##################
if test -n "`echo $LANG | grep ru_RU`"; then
	MSG_NO_SLAVE="Ведомый элемент не указано. Укажите хотя бы адрес или один из параметров UDP."
	TRAY_TEXT="запущен. Нажмите на значек, чтобы остановить его."
else
	MSG_NO_SLAVE="Slave is not specified. You must specify an IP or domain name, UDP input port, or UDP output port."
	TRAY_TEXT="launched. Press to icon to termiate it."
fi

NETSOURCE_COMMAND=jack_netsource

# If slave is not specified, netsource can't run
SLAVE_SPECIFIED=0

# Parsing GUI settings
if test -n "${slave_addr}"; then
	NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -H ${slave_addr}"
	SLAVE_SPECIFIED=1
fi
if test -n "${udp_in}"; then
	NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -r ${udp_in}"
        SLAVE_SPECIFIED=1
fi
if test -n "${udp_out}"; then
	NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -p ${udp_out}"
        SLAVE_SPECIFIED=1
fi

if test ${SLAVE_SPECIFIED} = 0 ; then
	echo ${MSG_NO_SLAVE}
	exit 0
fi

if test -n "${jack_client_name}"; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -N \"${jack_client_name}\""
else
	jack_client_name="JACK NetSource"
fi

if test -n "${jack_server_name}"; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -s ${jack_server_name}"
fi

if test "${delay}" != 0 ; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -n ${delay}"
fi

NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -i ${audio_ins}"
NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -o ${audio_outs}"
NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -I ${midi_ins}"
NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -O ${midi_outs}"

if test -n "${mtu}"; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -m ${mtu}"
fi

if test "${celt_bitrate}" != 0 ; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -c ${celt_bitrate}"
fi

if test -n "${bitdepth}"; then
        NETSOURCE_COMMAND="${NETSOURCE_COMMAND} -b ${bitdepth}"
fi

###############################################################
# Arguments parsed, time to launch
bash -c "${NETSOURCE_COMMAND}" &
NETSOURCE_PID=`pgrep -n -U \`whoami\` jack_netsource`
echo

# Checking, that found process is our
MSG_ALREADY_EXIST="Could not run process for new network source, because such process already exist.\nNETSOURCE_PID"=${NETSOURCE_PID}
if test -n "`ls -a ~ | grep .jack-netsource-gui.proc`"; then
	if test -n "`cat ~/.jack-netsource-gui.proc | grep $NETSOURCE_PID`"; then
		echo $MSG_ALREADY_EXIST
		exit 0
	fi
fi
echo "No"

# Registering our process in per-user list
echo $NETSOURCE_PID >> ~/.jack-netsource-gui.proc

zenity --window-icon="/usr/share/pixmaps/jack-netsource-gui.png" --notification --text=\
"${jack_client_name} ${TRAY_TEXT}"

kill -9 ${NETSOURCE_PID}

# Unregistering killed process from per-user list
cat ~/.jack-netsource-gui.proc | grep -v ${NETSOURCE_PID} > ~/.jack-netsource-gui.proc.tmp
cat ~/.jack-netsource-gui.proc.tmp > ~/.jack-netsource-gui.proc;
rm ~/.jack-netsource-gui.proc.tmp

exit 0
